==> hoogle-5.0.18.4-76-x86_64.pkg.tar.zst: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hoogle
version:              5.0.18.4
visibility:           public
id:                   hoogle-5.0.18.4-7Thtor5HxlYAFJQ3LoEffU
key:                  hoogle-5.0.18.4-7Thtor5HxlYAFJQ3LoEffU
license:              BSD-3-Clause
copyright:            Neil Mitchell 2004-2024
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://hoogle.haskell.org/
synopsis:             Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.

category:             Development
abi:                  009d02b373e9dc2021edb96778f42a4b
exposed:              True
exposed-modules:      Hoogle
hidden-modules:
    Paths_hoogle Action.CmdLine Action.Generate Action.Search
    Action.Server Action.Test Input.Cabal Input.Download Input.Haddock
    Input.Item Input.Reorder Input.Set Input.Settings Output.Items
    Output.Names Output.Tags Output.Types Query General.Conduit
    General.IString General.Log General.Store General.Str
    General.Template General.Timing General.Util General.Web

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hoogle
hs-libraries:         HShoogle-5.0.18.4-7Thtor5HxlYAFJQ3LoEffU
include-dirs:         /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4/include
includes:             include.h
depends:
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT base-4.16.4.0 binary-0.8.9.0
    blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    cmdargs-0.10.22-JQ4ivQZzeRmKKTWVSPDfjg
    conduit-1.3.6.1-ISJMpaJF58t3dEZ3o38RNe
    conduit-extra-1.3.6-8wnHA6l0vImF42f8TTslKW containers-0.6.5.1
    crypton-connection-0.3.2-CRnF9J89Sj4Y0mwjk0diN deepseq-1.4.6.1
    directory-1.3.6.2 extra-1.7.16-EWGdPHvQLeb5EiMAbHqdrp
    filepath-1.4.2.2 foundation-0.0.30-HGERhRs5JCDILoHDx95jS
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    haskell-src-exts-1.23.1-AENnvMzOJnRLlGbXypFMpv
    http-conduit-2.3.9.1-2TOVLZJGGXSFFrOFVKt87X
    http-types-0.12.4-EUtXhu021ZKEzVhlnug85Q
    js-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
    js-jquery-3.3.1-DMro9nRI8uHrJz9BhwNFy
    mmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    process-extras-0.7.4-8X3IYqjKgd8FFQR5nWxAg
    resourcet-1.2.6-7XRvu1GZSDsLOgaXXocelp
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    storable-tuple-0.1-3o4Z0zZ6Qoz9j8WhJvKENp
    tar-0.5.1.1-BWSSFc6YC8c7wv111YuSYr template-haskell-2.18.0.0
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    uniplate-1.6.13-13N6qNM0ncy2qFDgjyRb6W
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    wai-3.2.4-Jk3PC0rxUdX8PQLGr3R9HH
    wai-logger-2.5.0-1KKkainezFSAw4ezIHtxLE
    warp-3.3.30-BOdgvIaqH54GIfnpgbETx8
    warp-tls-3.4.9-CrjouuN3X7KEyxhsKjecHU
    zlib-0.6.3.0-3964NViQXyCEPE6a3KJUdx

haddock-interfaces:   /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html:         /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hoogle-5.0.18.4-78-x86_64.pkg.tar.zst: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hoogle
version:              5.0.18.4
visibility:           public
id:                   hoogle-5.0.18.4-FqaHwAAteb2C5XAb6PrQrk
key:                  hoogle-5.0.18.4-FqaHwAAteb2C5XAb6PrQrk
license:              BSD-3-Clause
copyright:            Neil Mitchell 2004-2024
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://hoogle.haskell.org/
synopsis:             Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.

category:             Development
abi:                  031a8e2c028d06ab442dc64733fe5c7f
exposed:              True
exposed-modules:      Hoogle
hidden-modules:
    Paths_hoogle Action.CmdLine Action.Generate Action.Search
    Action.Server Action.Test Input.Cabal Input.Download Input.Haddock
    Input.Item Input.Reorder Input.Set Input.Settings Output.Items
    Output.Names Output.Tags Output.Types Query General.Conduit
    General.IString General.Log General.Store General.Str
    General.Template General.Timing General.Util General.Web

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hoogle
hs-libraries:         HShoogle-5.0.18.4-FqaHwAAteb2C5XAb6PrQrk
include-dirs:         /usr/lib/ghc-9.2.8/site-local/hoogle-5.0.18.4/include
includes:             include.h
depends:
    QuickCheck-2.14.3-GYIzHRC98oX2ojVETG14rD
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT base-4.16.4.0 binary-0.8.9.0
    blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    cmdargs-0.10.22-JQ4ivQZzeRmKKTWVSPDfjg
    conduit-1.3.6.1-ISJMpaJF58t3dEZ3o38RNe
    conduit-extra-1.3.6-8wnHA6l0vImF42f8TTslKW containers-0.6.5.1
    crypton-connection-0.3.2-CRnF9J89Sj4Y0mwjk0diN deepseq-1.4.6.1
    directory-1.3.6.2 extra-1.7.16-EWGdPHvQLeb5EiMAbHqdrp
    filepath-1.4.2.2 foundation-0.0.30-HGERhRs5JCDILoHDx95jS
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    haskell-src-exts-1.23.1-AENnvMzOJnRLlGbXypFMpv
    http-conduit-2.3.9.1-paRktFnzJo4AkHA4rqzz6
    http-types-0.12.4-EUtXhu021ZKEzVhlnug85Q
    js-flot-0.8.3-CzHXKBaovyL8SpvVY5AoqF
    js-jquery-3.3.1-Eg4T8z5FbnzINUplzIZbfr
    mmap-0.5.9-Ev5kK7GQQYl5y5LE8RvEAs
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    process-extras-0.7.4-8X3IYqjKgd8FFQR5nWxAg
    resourcet-1.2.6-7XRvu1GZSDsLOgaXXocelp
    safe-0.3.21-AbNyMoK0ADF8qenYHSmRn2
    storable-tuple-0.1-3o4Z0zZ6Qoz9j8WhJvKENp
    tar-0.5.1.1-BWSSFc6YC8c7wv111YuSYr template-haskell-2.18.0.0
    text-1.2.5.0 time-1.11.1.1 transformers-0.5.6.2
    uniplate-1.6.13-13N6qNM0ncy2qFDgjyRb6W
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP
    wai-3.2.4-Jk3PC0rxUdX8PQLGr3R9HH
    wai-logger-2.5.0-FqaGZszjlxa1VBLqLePlrc
    warp-3.3.30-7KPOkCaiO9X3O0xCxPzw40
    warp-tls-3.4.9-F6imOX1k5H2Dq48L0nwSNT
    zlib-0.6.3.0-3964NViQXyCEPE6a3KJUdx

haddock-interfaces:   /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html:         /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
